@@ -41,7 +41,7 @@
 #define NCNN_AVX2 1
 #define NCNN_AVXVNNI 1
 #define NCNN_AVXVNNIINT8 1
-#define NCNN_AVXVNNIINT16 1
+#define NCNN_AVXVNNIINT16 0
 #define NCNN_AVXNECONVERT 1
 #define NCNN_AVX512 1
 #define NCNN_AVX512VNNI 1
@@ -69,7 +69,7 @@
 #define NCNN_BF16 1
 #define NCNN_FORCE_INLINE 1
 
-#define NCNN_VERSION_STRING "1.0.20250819"
+#define NCNN_VERSION_STRING "1.0.20250902"
 
 #include "ncnn_export.h"
 
@@ -86,7 +86,9 @@
 #endif // NCNN_THREADS
 
 #if __ANDROID_API__ >= 26
+#ifndef VK_USE_PLATFORM_ANDROID_KHR
 #define VK_USE_PLATFORM_ANDROID_KHR
+#endif
 #endif // __ANDROID_API__ >= 26
 
 namespace ncnn {
@@ -272,6 +274,7 @@ static inline void swap_endianness_32(void* x)
 #include <algorithm>
 #include <list>
 #include <vector>
+#include <stack>
 #include <string>
 #endif
 
